@@ -47,7 +47,7 @@
 #define MSG_SIZE_MAX 1024
 #define BUF_SIZE 256
 
-#define ALIGNMENT_TYPE_NUMBER 8
+#define ALIGNMENT_TYPE_NUMBER 6
 enum ALIGNMENT_TYPE
 {
 	TYPE_RULED = 0,
@@ -56,11 +56,7 @@ enum ALIGNMENT_TYPE
 	TYPE_AUTOCUT,
 	TYPE_RULED_COLOR,
 	TYPE_PATCH_COLOR,
-	TYPE_BAND_COLOR,
-
-	TYPE_PATCH_EXT,			/* Added for PM-G700 */
-	TYPE_PATCH_EXT_COLOR,
-
+	TYPE_BAND_COLOR
 };
 
 enum EXCEPTION_BITS
@@ -69,12 +65,7 @@ enum EXCEPTION_BITS
 	NAVI_EX_PM950C,
 	NAVI_EX_SC82S,
 	NAVI_EX_PM970C,
-	NAVI_EX_PM4000PX,
-	NAVI_EX_PMG700,
-	NAVI_EX_PXV600,
-	NAVI_EX_SC64_63S,
-	NAVI_EX_PMG800,
-	NAVI_EX_PMA850
+	NAVI_EX_PM4000PX
 };
 
 typedef struct _EKP_NAVI_INFO
@@ -192,8 +183,6 @@ static void align_ruled_navi (int);
 static void align_patch_navi (int);
 static void align_band_navi (int);
 static void align_autocut_navi (int);
-static void align_patch_ext_navi (int);
-
 static void cartridge_navi (int);
 static void black_cartridge (int);
 static void color_cartridge (int);
@@ -326,15 +315,12 @@ init_alignment (char* printer, int ruled, int patch, int band,
 	memcpy (_navi_info.align_path[TYPE_RULED], ruled_path, strlen (ruled_path) + 1);
 	memcpy (_navi_info.align_path[TYPE_PATCH], patch_path, strlen (patch_path) + 1);
 	memcpy (_navi_info.align_path[TYPE_BAND], band_path, strlen (band_path) + 1);
-
-	/* use PATCH path */
-	memcpy (_navi_info.align_path[TYPE_PATCH_EXT], patch_path, strlen (patch_path) + 1);
-
+	
 	if (!strcmp (model, "PM-890C"))
 	{
 		_navi_info.align_val[TYPE_RULED] = 3;
 		_navi_info.align_val[TYPE_PATCH] = 2;
-
+		
 		_navi_info.sn_flag = 1;
 		_navi_info.patch_dd = dd_pm890c;
 	}
@@ -360,7 +346,7 @@ init_alignment (char* printer, int ruled, int patch, int band,
 		if( !strcmp(model, "PM-860PT" ) ){
 			strcat(_navi_info.align_path[TYPE_PATCH], ".COLOR");
 		}
-
+		
 	}
 	else if (!strcmp (model, "PM-840C"))
 	{
@@ -370,11 +356,7 @@ init_alignment (char* printer, int ruled, int patch, int band,
 		_navi_info.patch_dd = dd_patch_pm840c;
 	}
 	else if (!strcmp (model, "Stylus C82 Series")
-	      || !strcmp (model, "PX-V700")
-	      || !strcmp (model, "CC-600PX")
-	      || !strcmp (model, "Stylus CX5100_5200 Series")
-	      || !strcmp (model, "Stylus CX5300_5400 Series")
-	      || !strcmp (model, "Stylus CX6300_6400 Series"))
+	      || !strcmp (model, "PX-V700") )
 	{
 		_navi_info.align_val[TYPE_RULED] = 5;
 		_navi_info.align_val[TYPE_RULED_COLOR] = 4;
@@ -382,8 +364,7 @@ init_alignment (char* printer, int ruled, int patch, int band,
 		_navi_info.align_val[TYPE_BAND_COLOR] = 1;
 		_navi_info.ex_bits = NAVI_EX_SC82S;
 	}
-	else if (!strcmp (model, "PM-970C")
-	      || !strcmp (model, "PM-980C") )
+	else if (!strcmp (model, "PM-970C"))
 	{
 		int inkset;
 
@@ -395,7 +376,7 @@ init_alignment (char* printer, int ruled, int patch, int band,
 
 		_navi_info.ruled_dd = dd_ruled_pm970c;
 		_navi_info.ex_bits = NAVI_EX_PM970C;
-
+		
 		if (strlen(_navi_info.align_path[TYPE_RULED]) + strlen(".x") + 1 > BUF_SIZE
 		    || strlen(_navi_info.align_path[TYPE_PATCH]) + strlen(".x") + 1 > BUF_SIZE) {
 			exit(1);
@@ -423,7 +404,7 @@ init_alignment (char* printer, int ruled, int patch, int band,
 
 		_navi_info.ruled_dd = dd_ruled_pm970c;
 		_navi_info.ex_bits = NAVI_EX_PM970C;
-
+		
 		_navi_info.ex_patch_dd = dd_patch_pm970c_7color;
 	}
 	else if (!strcmp (model, "Stylus Photo 2100_2200")
@@ -446,38 +427,6 @@ init_alignment (char* printer, int ruled, int patch, int band,
 
 		_navi_info.sn_flag = 1 ;
 	}
-	else if (!strcmp (model, "PM-G700") || !strcmp (model, "PM-A850") || !strcmp (model, "PM-D750")
-			|| !strcmp (model, "Stylus Photo R300_310") || !strcmp (model, "Stylus Photo R200_210")
-			|| !strcmp (model, "Stylus Photo RX600_610") || !strcmp (model, "Stylus Photo RX500_510"))
-	{
-		_navi_info.align_val[TYPE_PATCH_EXT]       = 4;
-		_navi_info.align_val[TYPE_PATCH_EXT_COLOR] = 4;
-		if( !strcmp (model, "PM-G700") || !strcmp (model, "PM-D750") || !strcmp (model, "Stylus Photo R300_310")
-			|| !strcmp (model, "Stylus Photo R200_210") || !strcmp (model, "Stylus Photo RX500_510"))
-			_navi_info.ex_bits = NAVI_EX_PMG700;
-		if( !strcmp (model, "PM-A850") || !strcmp (model, "Stylus Photo RX600_610") )
-			_navi_info.ex_bits = NAVI_EX_PMA850;
-
-	}else if (!strcmp (model, "Stylus C64_63 Series" ) || !strcmp (model, "PX-V500" )){
-		_navi_info.align_val[TYPE_PATCH_EXT]       = 4;
-		_navi_info.align_val[TYPE_PATCH_EXT_COLOR] = 4;
-		_navi_info.align_val[TYPE_BAND]       = 1;
-		_navi_info.align_val[TYPE_BAND_COLOR] = 1;
-		_navi_info.ex_bits = NAVI_EX_SC64_63S;
-
-	}else if (!strcmp (model, "PX-V600" ) || !strcmp (model, "Stylus C84_83 Series" )){
-		_navi_info.align_val[TYPE_PATCH_EXT]       = 5;
-		_navi_info.align_val[TYPE_PATCH_EXT_COLOR] = 4;
-		_navi_info.align_val[TYPE_BAND]       = 1;
-		_navi_info.align_val[TYPE_BAND_COLOR] = 1;
-		_navi_info.ex_bits = NAVI_EX_PXV600;
-
-	}
-	else if (!strcmp (model, "PM-G800"))
-	{
-		_navi_info.align_val[TYPE_PATCH_EXT]       = 3;
-		_navi_info.ex_bits = NAVI_EX_PMG800;
-	}
 	else
 	{
 		_navi_info.align_val[TYPE_RULED] = ruled;
@@ -559,8 +508,6 @@ alignment_navi (int page)
 			align_patch_navi (page);
 		} else if (_navi_info.align_val[TYPE_BAND] > 0) {
 			align_band_navi (page);
-		} else if (_navi_info.align_val[TYPE_PATCH_EXT] > 0) {
-			align_patch_ext_navi (page);
 		} else {
 			end_navi ();
 		}
@@ -1415,7 +1362,6 @@ align_band_navi (int page)
 	char command[BUF_SIZE];
 	int nwrite;
 	int i;
-	int len;
 
 	nwrite = 0;
 	memset (command, 0, sizeof (command));
@@ -1427,19 +1373,10 @@ align_band_navi (int page)
 		_navi_info.npix = 1;
 		_navi_info.pixmap[0] = gdk_pixmap_create_from_xpm_d (top->window, &_navi_info.mask[0], NULL, (gchar**)S1901);
 		
-		len = strlen (_navi_info.align_path[TYPE_BAND]) - strlen ("COLOR");
-		if (strncmp (_navi_info.align_path[TYPE_BAND] + len, "COLOR", strlen ("COLOR"))){
-			display_message (GTK_TEXT(text),
-				 _("A black horizontal alignment sheet will be printed.\n"
+		display_message (GTK_TEXT(text),
+				 _("A horizontal alignment sheet will be printed.\n"
 				   "Make sure that A4 or Letter size plain paper is loaded in the sheet feeder.\n\n"
 				   "Click \"Next\" when ready."));
-		}else{
-			display_message (GTK_TEXT(text),
-				 _("A color horizontal alignment sheet will be printed.\n"
-				   "Make sure that A4 or Letter size plain paper is loaded in the sheet feeder.\n\n"
-				   "Click \"Next\" when ready."));
-		}
-		
 		widget = lookup_widget (top, "cancel_button");
 		gtk_widget_show (widget);
 		widget = lookup_widget (top, "next_button");
@@ -1504,6 +1441,7 @@ align_band_navi (int page)
 		{
 			char wname[] = "align_combo_X";
 			int val;
+			int len;
 
 			wname[12] = '1' + i;
 			widget = lookup_widget (top, wname);
@@ -1511,38 +1449,19 @@ align_band_navi (int page)
 
 			len = strlen (_navi_info.align_path[TYPE_BAND]) - strlen ("COLOR");
 
-			/* model depend	*/
-			if(_navi_info.ex_bits == NAVI_EX_PXV600
-			|| _navi_info.ex_bits == NAVI_EX_SC64_63S ){
-				if (strncmp (_navi_info.align_path[TYPE_BAND] + len, "COLOR", strlen ("COLOR")))
-				{
-					alignment_set_dd[6] = 0x00;
-				}
-				else
-				{
-					alignment_set_dd[6] = 0x01;
-				}
-
-				alignment_set_dd[5] = 0x80;
-				alignment_set_dd[7] = val-4;
-				alignment_set_dd[8] = 0x02; 
-				memcpy (command + nwrite, alignment_set_dd, sizeof (alignment_set_dd));
-				nwrite += sizeof (alignment_set_dd);
-			}else{
-				if (strncmp (_navi_info.align_path[TYPE_BAND] + len, "COLOR", strlen ("COLOR")))
-				{
-					alignment_set[6] = 0x00;
-				}
-				else
-				{
-					alignment_set[6] = 0x01;
-				}
-
-				alignment_set[5] = 0x10 + i;
-				alignment_set[7] = val;
-				memcpy (command + nwrite, alignment_set, sizeof (alignment_set));
-				nwrite += sizeof (alignment_set);
+			if (strncmp (_navi_info.align_path[TYPE_BAND] + len, "COLOR", strlen ("COLOR")))
+			{
+				alignment_set[6] = 0x00;
 			}
+			else
+			{
+				alignment_set[6] = 0x01;
+			}
+
+			alignment_set[5] = 0x10 + i;
+			alignment_set[7] = val;
+			memcpy (command + nwrite, alignment_set, sizeof (alignment_set));
+			nwrite += sizeof (alignment_set);
 		}
 		memcpy (command + nwrite, alignment_save, sizeof (alignment_save));
 		nwrite += sizeof (alignment_save);
@@ -1577,7 +1496,7 @@ align_band_navi (int page)
 
 		memcpy (command, command_start, sizeof (command_start));
 		nwrite += sizeof (command_start);
-     
+      
 		for (i = 0; i < _navi_info.align_val[TYPE_BAND]; i++)
 		{
 			char wname[] = "align_combo_X";
@@ -1590,40 +1509,20 @@ align_band_navi (int page)
 
 			len = strlen (_navi_info.align_path[TYPE_BAND]) - strlen ("COLOR");
 
-			/* model depend	*/
-			if(_navi_info.ex_bits == NAVI_EX_PXV600
-			|| _navi_info.ex_bits == NAVI_EX_SC64_63S ){
-				if (strncmp (_navi_info.align_path[TYPE_BAND] + len, "COLOR", strlen ("COLOR")))
-				{
-					alignment_set_dd[6] = 0x00;
-				}
-				else
-				{
-					alignment_set_dd[6] = 0x01;
-				}
-
-				alignment_set_dd[5] = 0x80;
-				alignment_set_dd[7] = val-4; /* offset value */
-				alignment_set_dd[8] = 0x02; 
-				memcpy (command + nwrite, alignment_set_dd, sizeof (alignment_set_dd));
-				nwrite += sizeof (alignment_set_dd);
-			}else{
-				if (strncmp (_navi_info.align_path[TYPE_BAND] + len, "COLOR", strlen ("COLOR")))
-				{
-					alignment_set[6] = 0x00;
-				}
-				else
-				{
-					alignment_set[6] = 0x01;
-				}
-				alignment_set[5] = 0x10 + i;
-				alignment_set[7] = val;
-				memcpy (command + nwrite, alignment_set, sizeof (alignment_set));
-				nwrite += sizeof (alignment_set);
+			if (strncmp (_navi_info.align_path[TYPE_BAND] + len, "COLOR", strlen ("COLOR")))
+			{
+				alignment_set[6] = 0x00;
 			}
+			else
+			{
+				alignment_set[6] = 0x01;
+			}
+
+			alignment_set[5] = 0x10 + i;
+			alignment_set[7] = val;
+			memcpy (command + nwrite, alignment_set, sizeof (alignment_set));
+			nwrite += sizeof (alignment_set);
 		}
-		memcpy (command + nwrite, alignment_save, sizeof (alignment_save));
-		nwrite += sizeof (alignment_save);
 		memcpy (command + nwrite, alignment_set_end, sizeof (alignment_set_end));
 		nwrite += sizeof (alignment_set_end);
 		exec_printer (command, nwrite);
@@ -1639,250 +1538,6 @@ align_band_navi (int page)
 	return;
 };
 
-
-static void
-align_patch_ext_navi (int page)
-{
-	GtkWidget *text, *widget;
-	GtkWidget *top = _navi_info.top_dialog;
-
-	/*  char message[MSG_SIZE_MAX]; */
-	char command[BUF_SIZE];
-	int nwrite;
-	int len,i;
-
-	nwrite = 0;
-	memset (command, 0, sizeof (command));
-	text = lookup_widget (top, "message");
-
-	switch (page)
-	{
-	case 0:
-		_navi_info.npix = 1;
-		_navi_info.pixmap[0] = gdk_pixmap_create_from_xpm_d (top->window, &_navi_info.mask[0], NULL, (gchar**)S1901);
-
-		display_message (GTK_TEXT(text),
-				 _("The Print Head Alignment utility improves printout quality if used before printing in High Speed mode.\n\n"
-				   "If also fixes misaligned vertical lines and blurry printouts."));
-		widget = lookup_widget (top, "cancel_button");
-		gtk_widget_show (widget);
-		widget = lookup_widget (top, "next_button");
-		gtk_widget_show (widget);
-		break;
-
-	case 1:
-		_navi_info.npix = 1;
-		_navi_info.pixmap[0] = gdk_pixmap_create_from_xpm_d (top->window, &_navi_info.mask[0], NULL, (gchar**)S1901);
-
-		len = strlen (_navi_info.align_path[TYPE_PATCH_EXT]) - strlen ("COLOR");
-		if (strncmp (_navi_info.align_path[TYPE_PATCH_EXT] + len, "COLOR", strlen ("COLOR"))){
-			display_message (GTK_TEXT(text),
-				_("A black vertical alignment sheet will be printed.\n\n"
-				  "Make sure that the printer is turned on and connected to the computer.\n"
-				  "Also make sure that A4 size plain paper is loaded in the sheet feeder.\n\n"
-				  "Click \"Next\" when ready."));
-		}else{
-			display_message (GTK_TEXT(text),
-				_("A color vertical alignment sheet will be printed.\n\n"
-				  "Make sure that A4 size plain paper is loaded in the sheet feeder.\n"
-				  "Click \"Next\" when ready."));
-		}
-
-		widget = lookup_widget (top, "cancel_button");
-		gtk_widget_show (widget);
-		widget = lookup_widget (top, "next_button");
-		gtk_widget_show (widget);
-		break;
-
-	case 2:
-		_navi_info.npix = 1;
-		_navi_info.pixmap[0] = gdk_pixmap_create_from_xpm_d (top->window, &_navi_info.mask[0], NULL, (gchar**)S1901);
-
-		if (*_navi_info.align_path[TYPE_PATCH_EXT] == '\0')
-		{
-			/* in this case not happned! */
-		}
-		else
-		{
-			exec_printer_for_file (_navi_info.align_path[TYPE_PATCH_EXT]);
-		}
-
-
-		// depends on patch alignment count
-		if( _navi_info.align_val[TYPE_PATCH_EXT] == 5 ){
-			display_message (GTK_TEXT(text),
-				_("Look at the alignment sheet."
-				  "Find the square without any visible bands in sets #1 though #5.Select"
-				  "the number that corresponds to that square from the list below for all sets.\n\n"
-				  "If every square contains a band, select the square with the thinnest bandor bands.\n"
-				  "Then click Realignment.") );
-		}else if( _navi_info.align_val[TYPE_PATCH_EXT] == 4 ){
-			display_message (GTK_TEXT(text),
-				_("Look at the alignment sheet."
-				  "Find the square without any visible bands in sets #1 though #4.Select"
-				  "the number that corresponds to that square from the list below for all sets.\n\n"
-				  "If every square contains a band, select the square with the thinnest bandor bands.\n"
-				  "Then click Realignment.") );
-		}else if( _navi_info.align_val[TYPE_PATCH_EXT] == 3 ){
-			display_message (GTK_TEXT(text),
-				_("Look at the alignment sheet."
-				  "Find the square without any visible bands in sets #1 though #3.Select"
-				  "the number that corresponds to that square from the list below for all sets.\n\n"
-				  "If every square contains a band, select the square with the thinnest bandor bands.\n"
-				  "Then click Realignment.") );
-		}else{
-		}
-		widget = lookup_widget (top, "retry_button");
-		gtk_widget_show (widget);
-		widget = lookup_widget (top, "cancel_button");
-		gtk_widget_show (widget);
-		widget = lookup_widget (top, "ok_button");
-		gtk_widget_show (widget);
-
-		for (i = 0; i < _navi_info.align_val[TYPE_PATCH_EXT]; i++)
-		{
-			char label_name[] = "align_label_X";
-			char combo_name[] = "align_combo_X";
-
-			set_align_combo (i, 9, 5);
-
-			label_name[12] = '1' + i;
-			combo_name[12] = '1' + i;
-			widget = lookup_widget (top, label_name);
-			gtk_widget_show (widget);
-			widget = lookup_widget (top, combo_name);
-			gtk_widget_show (widget);
-		}
-		break;
-
-	case 3:
-	case 4: /* realignment */
-		_navi_info.npix = 0;
-
-		memcpy (command, command_start, sizeof (command_start));
-		nwrite += sizeof (command_start);
-
-		{
-			for (i = 0; i < _navi_info.align_val[TYPE_PATCH_EXT]; i++)
-			{
-				char wname[] = "align_combo_X";
-				int val;
-				int len;
-				int modulo = _navi_info.align_val[TYPE_PATCH_EXT];
-				static char align_val[] = {-6,-4,-2,-1,0,1,2,4,6 };
-				
-				wname[12] = '1' + i;
-				widget = lookup_widget (top, wname);
-				val = atoi (gtk_entry_get_text (GTK_ENTRY(GTK_COMBO(widget)->entry)));
-				/* model depend	*/
-				if(_navi_info.ex_bits == NAVI_EX_PMG800 ){
-					int j = 0;
-
-					alignment_set_dd[8] = 0x02;
-					for( j = 0; j < 3; j++ ){
-						/* not checked color */
-						alignment_set_dd[5] = i+1;
-						alignment_set_dd[6] = j+1;
-						if( j == 2 )
- 							alignment_set_dd[7] = 0; /* value */
-						else
- 							alignment_set_dd[7] = align_val[val-1]; /* value */			
-						/* write dd command */
-						memcpy (command + nwrite, alignment_set_dd, sizeof (alignment_set_dd));
-						nwrite += sizeof (alignment_set_dd);
-					}
-				
-					for( j = 0; j < 3; j++ ){
-						/* not checked color */
-						alignment_set_dd[5] = i+4;
-						alignment_set_dd[6] = j+1;
-						if( j == 2 )
- 							alignment_set_dd[7] = 0; /* value */
-						else
- 							alignment_set_dd[7] = align_val[val-1]; /* value */			
-						/* write dd command */
-						memcpy (command + nwrite, alignment_set_dd, sizeof (alignment_set_dd));
-						nwrite += sizeof (alignment_set_dd);
-					}
-				}else{
-					/* first dd  */
-					len = strlen (_navi_info.align_path[TYPE_PATCH_EXT]) - strlen ("COLOR");
-					if (strncmp (_navi_info.align_path[TYPE_PATCH_EXT] + len, "COLOR", strlen ("COLOR"))){
-						alignment_set_dd[5] = (i+1)%modulo;
-						alignment_set_dd[6] = 0x00;
-					}else{
-						if(_navi_info.ex_bits == NAVI_EX_PXV600 ){
-							/* model depndent color pattern 4/mono patern 5 */
-							/* skip first index and ... 			*/
-							alignment_set_dd[5] = (i+2)%(modulo+1);
-						}else{
-							alignment_set_dd[5] = (i+1)%modulo;
-						}
-						alignment_set_dd[6] = 0x01;
-					}
-					alignment_set_dd[8] = 0x02;
-					alignment_set_dd[7] = align_val[val-1]; /* value */			
-					memcpy (command + nwrite, alignment_set_dd, sizeof (alignment_set_dd));
-					nwrite += sizeof (alignment_set_dd);
-
-					/* model depend	*/
-					if(_navi_info.ex_bits == NAVI_EX_PMG700 ){
-						/* second dd */
-						alignment_set_dd[5] += 0x10;
-						memcpy (command + nwrite, alignment_set_dd, sizeof (alignment_set_dd));
-						nwrite += sizeof (alignment_set_dd);
-					}
-				}
-			}
-		}
-		memcpy (command + nwrite, alignment_save, sizeof (alignment_save));
-		nwrite += sizeof (alignment_save);
-		memcpy (command + nwrite, alignment_set_end, sizeof (alignment_set_end));
-		nwrite += sizeof (alignment_set_end);
-		exec_printer (command, nwrite);
-
-
-		if( page == 4 ){
-			/* realignment */
-			set_navi_page (1);
-			break;
-		}
-
-		if (_navi_info.align_val[TYPE_PATCH_EXT_COLOR])
-		{
-			if ((strlen (_navi_info.align_path[TYPE_PATCH_EXT]) + strlen (".COLOR")) < BUF_SIZE)
-			{
-				_navi_info.align_val[TYPE_PATCH_EXT] = _navi_info.align_val[TYPE_PATCH_EXT_COLOR];
-				strcat (_navi_info.align_path[TYPE_PATCH_EXT], ".COLOR");
-				_navi_info.align_val[TYPE_PATCH_EXT_COLOR] = 0;
-				set_navi_page (1);
-			}
-			else
-			{
-				_navi_info.align_val[TYPE_PATCH_EXT_COLOR] = 0;
-				_navi_info.align_val[TYPE_PATCH_EXT] = 0;
-			}
-		}
-		else
-		{
-			_navi_info.align_val[TYPE_PATCH_EXT] = 0;
-
-		}
-
-		set_navi_page (1);
-		break;
-
-	default:
-		fprintf (stderr, "error page (%d).\n", page);
-		end_navi ();
-		break;
-	}
-
-
-
-};
-
-
 static void
 align_autocut_navi (int page)
 {
@@ -2035,12 +1690,13 @@ set_align_combo (int number, int list, int val)
 	gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (widget)->entry), _(numstr));
 }
 
+
 static void
 exec_printer (char *command, int size)
 {
 	FILE *fp;
 
-#if DEBUG
+#ifdef DEBUG
 	int i;
 
 	fprintf(stderr, "[Command Dump]\n");
