@@ -38,7 +38,9 @@
 #include <math.h>
 #include "xMode.h"
 #include "ekpcom.h"
+#include "getstat.h"
 #include "setup.h"
+
 typedef struct _IO_SIGDATA
 {
 	GtkWidget *filewin;
@@ -50,8 +52,8 @@ extern void *opt_address[EX_N_OPT];
 extern char *input_file;
 extern char *output_file;
 extern int output_type;
-
 extern UTIL_PACK pips_util_pack;
+extern GtkWidget *margin_frame_;
 
 static GtkWidget* commonPixmapLoad(char*);
 
@@ -68,12 +70,14 @@ static void selectPackVisibility(SELECT_PACK*, int);
 static void selectPackChengeValue(GtkWidget*, SELECT_PACK*);
 
 static SPIN_PACK* spinPackAdd(int);
+static void spinPackSetSensitive (SPIN_PACK *, int);
 static void spinPackChengeValue(GtkAdjustment*, SPIN_PACK*);
 
 static ADJUSTMENT_PACK* adjustmentPackAdd(int);
 static void adjustmentPackSetSensitive(ADJUSTMENT_PACK*, int);
 static void adjustmentPackChengeValue(GtkAdjustment*, ADJUSTMENT_PACK*);
 static void adjustmentPackChengeEntry(GtkWidget*, ADJUSTMENT_PACK*);
+static void adjustmentPackCheckEntry(GtkWidget*, GdkEvent*, ADJUSTMENT_PACK*);
 
 static void ioOutputTypeSet(GtkWidget*, gpointer);
 static GtkWidget* ioPackButton(GtkWidget*);
@@ -130,14 +134,19 @@ commonLabelCall (int id, OPTION_DATA *data)
 void
 commonSetOptionsSensitive (void)
 {
-	int i, j, count;
+	int i, j, count, offset;
 	int flag[ENTRY_MAX];
 	char *new_entry[ENTRY_MAX];
 	const short *mode;
 	SEP_INIT_PARAM *sepip_lite;
 	OPTION_DATA *data;
 	SELECT_PACK *sp;
+	int bin_type;
 
+	/* å */
+	int mw_type;
+	int once;
+	
 	sepip_lite = (SEP_INIT_PARAM *)malloc (sizeof (SEP_INIT_PARAM));
 
 	count = 0;
@@ -180,32 +189,39 @@ commonSetOptionsSensitive (void)
 	/* ѥ᡼,Υߡ */
 	sepip_lite->src_resolution.x = sepip_lite->halftone_type
 		= sepip_lite->high_speed = sepip_lite->qlevel
-		= sepip_lite->media_type = -1;
+		= sepip_lite->media_type = sepip_lite->mw_type
+		= sepip_lite->bin_id = sepip_lite->inkset = -1;
 
 	/* make new media type entry */
-#ifdef USE_AUTO_TRIM_4
+#if defined(USE_AUTO_TRIM_4) || defined(INK_CHANGE_SYSTEM)
 	{
+#ifdef USE_AUTO_TRIM_4
 		sepip_lite->bin_id = getValueOfDatabases (P_BIN, (char *)options[P_BIN]);
 		sepip_lite->prt_format = getValueOfDatabases (P_INK, (char *)options[P_INK]);
+#endif /* USE_AUTO_TRIM_4 */
+#ifdef INK_CHANGE_SYSTEM
+		sepip_lite->inkset = getValueOfDatabases (P_INKSET, (char *)options[P_INKSET]);
+#endif /* INK_CHANGE_SYSTEM */
 
 		data = opt_all[P_MEDIA_TYPE].data;
 		for (i = 0; data[i].value != END_ARRAY; i++)
 			flag[i] = FALSE;
-
-		for (i = 0; i < mode[0]; i++)
+		
+		for (i = 0; mode[i * MODE_ITEM] >= 0; i++)
 		{
 			if (!printModeCheck (mode, i, sepip_lite))
 			{
 				for (j = 0; data[j].value != END_ARRAY; j++)
 				{
-					if (data[j].value == mode[i * MODE_ITEM + 1])
+					offset = i * MODE_ITEM;
+					if (data[j].value == mode[offset + MOFS_MEDIA])
 					{
 						flag[j] = TRUE;
 					}
 				}
 			}
 		}
-
+	
 		count = 0;
 		for (i = 0; data[i].value != END_ARRAY; i++)
 		{
@@ -213,11 +229,18 @@ commonSetOptionsSensitive (void)
 			{
 				new_entry[count++] = data[i].rsc_name;
 			}
+#ifdef	PM940C
+			else{
+				if( data[i].value & SILENT_MASK ){
+					new_entry[count++] = data[i].rsc_name;
+				}
+			}
+#endif
 		}
 		new_entry[count] = NULL;
 		selectPackSetSensitive ((SELECT_PACK *)opt_address[P_MEDIA_TYPE], new_entry);
 	}
-#endif /* USE_AUTO_TRIM_4 */
+#endif /* define(USE_AUTO_TRIM_4) || define(INK_CHANGE_SYSTEM) */
 
 	/* make new resolution entry */
 	sepip_lite->media_type = getValueOfDatabases (P_MEDIA_TYPE, (char *)options[P_MEDIA_TYPE]);
@@ -225,16 +248,20 @@ commonSetOptionsSensitive (void)
 
 	for (i = 0; data[i].value != END_ARRAY; i++)
 		flag[i] = FALSE;
-	sepip_lite->media_type = getValueOfDatabases (P_MEDIA_TYPE, (char *)options[P_MEDIA_TYPE]);
-  
+	
 	count = 0;
-	for (i = 0; i < mode[0]; i++)
+	for (i = 0; mode[i * MODE_ITEM] >= 0; i++)
 	{
 		if (!printModeCheck (mode, i, sepip_lite))
 		{
 			for (j = 0; data[j].value != END_ARRAY; j++)
 			{
-				if (mode[i * MODE_ITEM + 2] & (int)ldexp (1.0, j))
+				offset = i * MODE_ITEM;
+#ifdef USE_360_DRAFT
+				if (mode[offset + MOFS_INPUT] & (int)ldexp (1.0, j + 1))
+#else
+				if (mode[offset + MOFS_INPUT] & (int)ldexp (1.0, j))
+#endif /* USE_360_DRAFT */
 				{
 					flag[j] = TRUE;
 				}
@@ -258,23 +285,23 @@ commonSetOptionsSensitive (void)
 	data = opt_all[P_QUALITY_LEVEL].data;
 
 	for (i = 0; data[i].value != END_ARRAY; i++) flag[i] = FALSE;
-	for (i = 0; i < mode[0]; i++)
+	for (i = 0; mode[i * MODE_ITEM] >= 0; i++)
 	{
 		if (!printModeCheck (mode, i, sepip_lite))
 		{
-			unsigned int bit = mode[i * MODE_ITEM + 5];
+			unsigned int bit = mode[i * MODE_ITEM + MOFS_QUALITY];
 			switch (sepip_lite->src_resolution.x)
 			{
 
 			case 120:
 			case 180: flag[0] = TRUE;
-	      
+     
 			case 720: bit = bit >> 4;
 			case 360: bit = bit >> 4;
 
-#if SC580 || SC480 || SC40S || SC20S
+#if USE_RESOLUTION_240
 			case 240: bit = bit >> 4;
-#endif
+#endif /* USE_RESOLUTION_240 */
 
 			}
 			bit &= 0x0f;
@@ -292,40 +319,72 @@ commonSetOptionsSensitive (void)
 	selectPackSetSensitive ((SELECT_PACK *)opt_address[P_QUALITY_LEVEL], new_entry);
 	selectPackVisibility ((SELECT_PACK *)opt_address[P_QUALITY_LEVEL], i - 1);
 
-	/* check high speed sensitive */
-	data = opt_all[P_QUALITY_LEVEL].data;
 
+	/* check micro weave sensitive */
+	data = opt_all[P_QUALITY_LEVEL].data;
 	for (i = 0; data[i].value != END_ARRAY; i++)
 		flag[i] = FALSE;
 	sepip_lite->qlevel = getValueOfDatabases (P_QUALITY_LEVEL, (char *)options[P_QUALITY_LEVEL]);
 
-	for (i = 0; i < mode[0]; i++)
+	once = FALSE;
+	mw_type = 0;
+	for (i = 0; mode[i * MODE_ITEM] >= 0; i++)
 	{
 		if (!printModeCheck (mode, i, sepip_lite))
 		{
-			checkPackSetSensitive ((CHECK_PACK *)opt_address[P_HIGH_SPEED], mode[i * MODE_ITEM + 4]);
-			goto OUT;
+			
+			offset = i * MODE_ITEM;
+			if( once ){
+				/* Same mode again */
+	                        if( mode[offset + MOFS_MICRO_WEAVE] != mw_type ){
+					mw_type = 2;
+					break;
+				}
+			}else{
+	                         mw_type = mode[offset + MOFS_MICRO_WEAVE];
+				 if( mw_type == 2 ){
+					/* On/Off */
+				 	break;
+			         }
+				 once = TRUE;
+		 	}
 		}
 	}
- OUT:
+
+	checkPackSetSensitive ((CHECK_PACK *)opt_address[P_MICRO_WEAVE], mw_type );
+
+	/* check high speed sensitive */
+	sepip_lite->mw_type = getValueOfDatabases (P_MICRO_WEAVE, (char *)options[P_MICRO_WEAVE]);
+
+	for (i = 0; mode[i * MODE_ITEM] >= 0; i++)
+	{
+		if (!printModeCheck (mode, i, sepip_lite))
+		{
+			offset = i * MODE_ITEM;
+			checkPackSetSensitive ((CHECK_PACK *)opt_address[P_HIGH_SPEED], mode[offset + MOFS_HIGH_SPEED]);
+			goto OUT_HS;
+		}
+	}
+ OUT_HS:
   
   
 	/* make halftonetype entry */
 	data = opt_all[P_HALF_TONE].data;
 	for (i = 0; data[i].value != END_ARRAY; i++) flag[i] = FALSE;
 
-	for (i = 0; i < mode[0]; i++)
+	for (i = 0; mode[i * MODE_ITEM] >= 0; i++)
 	{
 		if (!printModeCheck(mode, i, sepip_lite))
 		{
 			for (j = 0; data[j].value != END_ARRAY; j++)
 			{
-				if (mode[i * MODE_ITEM + 3] & (int)ldexp(1.0, j)) flag[j] = TRUE;
+				offset = i * MODE_ITEM;
+				if (mode[offset + MOFS_HALFTONE] & (int)ldexp(1.0, j)) flag[j] = TRUE;
 			}
-			goto OUT2;
+			goto OUT_HT;
 		}
 	}
- OUT2:
+ OUT_HT:
   
 	count = 0;
 	for (i = 0; data[i].value != END_ARRAY; i++)
@@ -334,11 +393,16 @@ commonSetOptionsSensitive (void)
 	new_entry[count] = NULL;
 	selectPackSetSensitive ((SELECT_PACK *)opt_address[P_HALF_TONE], new_entry);
   
-	free (sepip_lite);
-#ifdef ROLL_PAPER
+
+	bin_type = getValueOfDatabases (P_BIN, (char *)options[P_BIN]);
+
+	/* Media size */
 	{
 		char **msentry;
-		switch (getValueOfDatabases (P_BIN, (char *)options[P_BIN]))
+#ifdef	PM940C		
+		char **msentrySilent;
+#endif
+		switch (bin_type)
 		{
 		case PIPS_BIN_AUTO: msentry = mediaSizeEntry; break;
 		case PIPS_BIN_USER: msentry = mediaSizeEntry_R; break;
@@ -351,17 +415,96 @@ commonSetOptionsSensitive (void)
 #endif /* PM820_3300C */
 #ifdef USE_AUTO_TRIM_4
 		case PIPS_BIN_AUTO_TRIM_4: msentry = mediaSizeEntry_NMA; break;
-#endif /* USE_AUTO_TRIM_4 */
+#endif
 
 		default: abort ();
 		}
+
+#ifdef	PM940C
+		/* alloc work buffer, 25 means no. of paper */ 
+		msentrySilent = (char **)malloc(sizeof(char *) * 25 );
+		if( !msentrySilent ){
+			/* no memory */
+			abort();
+		}
+				 
+		/* resetting mediaSizeEntry for Silent Feed */
+		if( !strcmp( "PLAIN_SILENT", options[P_MEDIA_TYPE] )
+		||  !strcmp( "EPP_SILENT", options[P_MEDIA_TYPE] ) ){
+			int ok,i,j,k;
+			k= 0;
+			for( i=0; msentry[i] ; i++ ){
+				ok=1;
+				for( j=0; mediaSizeReject[j];j++ ){
+					if( !strcmp(mediaSizeReject[j],msentry[i]) ){
+						ok = 0;
+						break;
+					}
+				}
+				if( ok ){
+					msentrySilent[k++] = msentry[i];
+				}
+			}
+			msentrySilent[k] = (char *)0;
+			msentry = msentrySilent;
+		}
+#endif
+		
 		selectPackSetSensitive ((SELECT_PACK *)opt_address[P_MEDIA_SIZE], msentry);
+
+#ifdef	PM940C
+		/* clean up  */
+		if( msentrySilent ) free( msentrySilent );
+#endif
 	}
-#endif /* ROLL_PAPER */
+
+	/* Auto cut */
+	{
+		data = opt_all[P_AUTO_CUT].data;
+
+		new_entry[0] = data[0].rsc_name;
+
+		if ((bin_type == PIPS_BIN_USER
+		     || bin_type == PIPS_BIN_TRIMBANNER)
+		    && sepip_lite->mw_type == PIPS_MW_ON
+		    && autoCutEntry[1] != NULL)
+		{
+			new_entry[1] = data[1].rsc_name;
+
+			if (bin_type == PIPS_BIN_TRIMBANNER)
+			{
+				new_entry[2] = data[2].rsc_name;
+				new_entry[3] = NULL;
+			}
+			else
+			{
+				new_entry[2] = NULL;
+			}
+		}
+		else
+		{
+			new_entry[1] = NULL;
+		}
+		selectPackSetSensitive ((SELECT_PACK *)opt_address[P_AUTO_CUT], new_entry);
+	}
+
+
+	free (sepip_lite);
 
 #ifdef CONV_VERSION2
 	margin_abjset ();
 #endif /* CONV_VERSION2 */
+
+	if ((char *)options[P_FIT_PAGE])
+	{			/* ON */
+		spinPackSetSensitive ((SPIN_PACK *)opt_address[P_SCALE], FALSE);
+		gtk_widget_set_sensitive(margin_frame_, FALSE);
+	}
+	else
+	{			/* OFF */
+		spinPackSetSensitive ((SPIN_PACK *)opt_address[P_SCALE], TRUE);
+		gtk_widget_set_sensitive(margin_frame_, TRUE);
+	}
 }
 
 
@@ -391,23 +534,23 @@ static void radioPackChengeValue(GtkWidget *widget, RADIO_PACK *rp)
 	int i, id;
 
 	id = rp->id;
-	for(i = 0; (node = g_slist_nth(rp->group, i)) != NULL; i++)
+	for (i = 0; (node = g_slist_nth (rp->group, i)) != NULL; i++)
 	{
 		radio = (GtkWidget *)node->data;
-		if(radio == widget)
+		if (radio == widget)
 		{
 			options[id] = (void *)opt_all[id].data[i].rsc_name;
 			break;
 		}
 	}
-	commonSetOptionsSensitive();
+	commonSetOptionsSensitive ();
 }
 
 GtkWidget* radioPackNew(char *map, char *entry[], int id)
 {
 	GtkWidget *frame;
 	GtkWidget *hbox;
-	GtkWidget *pixmap;
+	GtkWidget *pixmap=0;
 	GtkWidget *radio;
 	GSList *group;
 	RADIO_PACK *rp;
@@ -418,59 +561,57 @@ GtkWidget* radioPackNew(char *map, char *entry[], int id)
 	rp = radioPackAdd(id);
 	sig_id = opt_address[id];
 
-	frame = gtk_frame_new(commonLabelCall(id, NULL));
-	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_IN);
+	frame = gtk_frame_new (commonLabelCall(id, NULL));
+	gtk_frame_set_shadow_type (GTK_FRAME(frame), GTK_SHADOW_ETCHED_IN);
 
-	hbox = gtk_hbox_new(FALSE, GTK_BORDER);
+	hbox = gtk_hbox_new (FALSE, GTK_BORDER);
 
-	if(map) pixmap = commonPixmapLoad(map);
+	if (map) pixmap = commonPixmapLoad (map);
   
-	for(offset = 0; entry[offset] != NULL; offset++);
-	if((data = databasesCall(CALL_FOR_RSC_NAME, id, (void*)entry[--offset])) == NULL)
+	for (offset = 0; entry[offset] != NULL; offset++);
+	if ((data = databasesCall (CALL_FOR_RSC_NAME, id, (void*)entry[-- offset])) == NULL)
 		return NULL;
 
-	radio = gtk_radio_button_new_with_label(NULL, commonLabelCall(id, data));
-
-	if(!strcmp(data->rsc_name, (char*)options[id]))
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio), TRUE);
+	radio = gtk_radio_button_new_with_label (NULL, commonLabelCall(id, data));
 
+	if (!strcmp (data->rsc_name, (char*)options[id]))
+		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(radio), TRUE);
 	else
-		gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio), FALSE);
+		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(radio), FALSE);
 
-	gtk_signal_connect(GTK_OBJECT(radio), "pressed",
-			   GTK_SIGNAL_FUNC(radioPackChengeValue), sig_id);
+	gtk_signal_connect (GTK_OBJECT(radio), "pressed",
+			    GTK_SIGNAL_FUNC(radioPackChengeValue), sig_id);
+	gtk_box_pack_start (GTK_BOX(hbox), radio, FALSE, FALSE, 0);
+	gtk_widget_show (radio);
 
-	gtk_box_pack_start(GTK_BOX(hbox), radio, FALSE, FALSE, 0);
-	gtk_widget_show(radio);
-
-	group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio));
+	group = gtk_radio_button_group (GTK_RADIO_BUTTON(radio));
 
 	offset--;
-	for(; offset >= 0; offset--)
+	for (; offset >= 0; offset --)
 	{
-		if((data = databasesCall(CALL_FOR_RSC_NAME, id, (void*)entry[offset])) == NULL)
+		if ((data = databasesCall (CALL_FOR_RSC_NAME, id, (void*)entry[offset])) == NULL)
 			return NULL;
-	  
-		radio = gtk_radio_button_new_with_label(group, commonLabelCall(id, data));
 
-		if(!strcmp(data->rsc_name, (char*)options[id]))
-			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio), TRUE);
+		radio = gtk_radio_button_new_with_label (group, commonLabelCall(id, data));
 
+		if (!strcmp(data->rsc_name, (char*)options[id]))
+			gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(radio), TRUE);
 		else
-			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radio), FALSE);
+			gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(radio), FALSE);
+		
+		gtk_signal_connect (GTK_OBJECT(radio), "pressed",
+				    GTK_SIGNAL_FUNC(radioPackChengeValue), sig_id);
+		gtk_box_pack_start (GTK_BOX(hbox), radio, FALSE, FALSE, 0);
+		gtk_widget_show (radio);
 
-		gtk_signal_connect(GTK_OBJECT(radio), "pressed",
-				   GTK_SIGNAL_FUNC(radioPackChengeValue), sig_id);
-		gtk_box_pack_start(GTK_BOX(hbox), radio, FALSE, FALSE, 0);
-		gtk_widget_show(radio);
-		group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio));
+		group = gtk_radio_button_group (GTK_RADIO_BUTTON(radio));
 	}
-
-	gtk_container_add(GTK_CONTAINER(frame), hbox);
-	gtk_widget_show(hbox);
+  
+	gtk_container_add (GTK_CONTAINER(frame), hbox);
+	gtk_widget_show (hbox);
 
 	rp->id = id;
-	if(map) rp->pixmap = pixmap;
+	if (map) rp->pixmap = pixmap;
 	rp->group = group;
   
 	gtk_container_set_border_width (GTK_CONTAINER (frame), GTK_BORDER);
@@ -534,7 +675,7 @@ static void checkPackChengeValue(GtkWidget *widget, CHECK_PACK *cp)
 GtkWidget* checkPackNew(char *map, int id)
 {
 	GtkWidget *hbox;
-	GtkWidget *pixmap;
+	GtkWidget *pixmap=0;
 	GtkWidget *check;
 	CHECK_PACK *cp;
 	void *sig_id;
@@ -552,6 +693,7 @@ GtkWidget* checkPackNew(char *map, int id)
 	check = gtk_check_button_new_with_label(commonLabelCall(id, NULL));
 	gtk_widget_show(check);
 	gtk_box_pack_start(GTK_BOX(hbox), check, TRUE, TRUE, 0);
+
 	if(options[id] != NULL) gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check), TRUE);
 	else gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check), FALSE);
 
@@ -653,7 +795,7 @@ static void selectPackChengeValue(GtkWidget *widget, SELECT_PACK *sp)
 GtkWidget* selectPackNew(char *map, char *entry[], int id)
 {
 	GtkWidget *hbox;
-	GtkWidget *pixmap;
+	GtkWidget *pixmap=0;
 	GtkWidget *label;
 	GtkWidget *optmenu;
 	GtkWidget *menu;
@@ -661,7 +803,7 @@ GtkWidget* selectPackNew(char *map, char *entry[], int id)
 	SELECT_PACK *sp;
 	OPTION_DATA *data;
 	char *title;
-	int i, def;
+	int i, def=0;
 	gpointer sig_id;
 
 	sp = selectPackAdd(id);
@@ -724,7 +866,12 @@ static SPIN_PACK* spinPackAdd(int id)
 }
 
 
-/* spinPackSetSensitive ̤ */
+static void spinPackSetSensitive (SPIN_PACK *spp, int flag)
+{
+	if(spp->pixmap) gtk_widget_set_sensitive(spp->pixmap, flag);
+	gtk_widget_set_sensitive(spp->label, flag);
+	gtk_widget_set_sensitive(spp->spin, flag);
+}
 
 static void spinPackChengeValue(GtkAdjustment *adj, SPIN_PACK *spp)
 {
@@ -740,7 +887,7 @@ static void spinPackChengeValue(GtkAdjustment *adj, SPIN_PACK *spp)
 GtkWidget* spinPackNew(char *map, int id, double param[])
 {
 	GtkWidget *hbox;
-	GtkWidget *pixmap;
+	GtkWidget *pixmap=0;
 	GtkWidget *label;
 	GtkObject *adj;
 	GtkWidget *spin;
@@ -868,10 +1015,38 @@ static void adjustmentPackChengeEntry(GtkWidget* widget,
 	return;
 }
 
+static void adjustmentPackCheckEntry(GtkWidget* widget,
+				     GdkEvent* event, ADJUSTMENT_PACK *ap )
+{
+	int id, *opt_value, len;
+	char* strval;
+
+	/* check only for NULL */
+
+	id = ap->id;
+	opt_value = (int *)options[id];
+	strval = (char*)gtk_entry_get_text(GTK_ENTRY(widget));
+
+	
+	len = strlen(strval);
+	/* ʸ¸ߤƤ, 夬0ǤʤOK */
+	if ((len == 0)
+	    || ((len > 1) && (((strval[0] == '0') || (strval[0] == '-')) && (strval[1] == '0'))))
+	{
+		gtk_signal_handler_block_by_data (GTK_OBJECT(widget), (gpointer)ap);
+		/* *opt_value = 0; */
+		sprintf (strval, "%d", *opt_value );
+		gtk_entry_set_text(GTK_ENTRY(widget), strval);
+		gtk_signal_handler_unblock_by_data (GTK_OBJECT(widget), (gpointer)ap);
+	}
+	return;
+}
+
+
 GtkWidget* adjustmentPackNew(char *map, int id, double param[])
 {
 	GtkWidget *hbox;
-	GtkWidget *pixmap;
+	GtkWidget *pixmap=0;
 	GtkWidget *label;
 	GtkObject *adj;
 	GtkWidget *entry;
@@ -881,6 +1056,7 @@ GtkWidget* adjustmentPackNew(char *map, int id, double param[])
 	gpointer sig_id;
 	int *value;
 
+
 	ap = adjustmentPackAdd(id);
 	sig_id = opt_address[id];
   
@@ -907,6 +1083,9 @@ GtkWidget* adjustmentPackNew(char *map, int id, double param[])
 	gtk_widget_show(entry);
 	gtk_signal_connect(GTK_OBJECT(entry), "changed",
 			   GTK_SIGNAL_FUNC(adjustmentPackChengeEntry), sig_id);
+	/* focus out */
+	gtk_signal_connect(GTK_OBJECT(entry), "focus_out_event",
+			   GTK_SIGNAL_FUNC(adjustmentPackCheckEntry), sig_id );
 
 	adj = gtk_adjustment_new(*value, param[0], param[1],
 				 param[2], param[3], param[4]);
@@ -1112,13 +1291,8 @@ margin_default_set (GtkWidget *widget, void* data)
 	SPIN_PACK *mgx = (SPIN_PACK*)opt_address[P_MARGIN_X];
 	SPIN_PACK *mgy = (SPIN_PACK*)opt_address[P_MARGIN_Y];
 
-#ifdef ROLL_PAPER
 	lp_paper = call_paper_conf ((char*)options[P_BIN],
 				    (char*)options[P_MEDIA_SIZE]);
-#else
-	lp_paper = call_paper_conf ("",
-				    (char*)options[P_MEDIA_SIZE]);
-#endif /* ROLL_PAPER */
   
 	gtk_adjustment_set_value (GTK_ADJUSTMENT(mgx->adj),
 				  (gfloat)DOT_TO_MM(lp_paper->margin_x));
@@ -1134,7 +1308,6 @@ margin_abjset (void)
 	LP_PAPER_CONF lp_paper;
 	char bin_name[10];
 
-#ifdef ROLL_PAPER
 	SPIN_PACK *mgx = (SPIN_PACK*)opt_address[P_MARGIN_X];
 	SPIN_PACK *mgy = (SPIN_PACK*)opt_address[P_MARGIN_Y];
 
@@ -1163,10 +1336,6 @@ margin_abjset (void)
 		gtk_widget_set_sensitive (mgy->spin, TRUE);
 	}
 
-#else
-	strcpy (bin_name, "");
-#endif
-
 	lp_paper = call_paper_conf (bin_name, (char*)options[P_MEDIA_SIZE]);
 
 	margin_updata (P_MARGIN_X, lp_paper->margin_x, lp_paper->margin_x + lp_paper->area_x);
@@ -1182,9 +1351,9 @@ margin_updata (int id, long def, long max)
 	SPIN_PACK *mg = (SPIN_PACK*)opt_address[id];
 
 	adj = gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON(mg->spin));
-	adj->upper = DOT_TO_MM(max);
+	adj->upper = DOT_TO_MM(max)  - 1; /* ޡͤ1mmʤꤹ */
 	gtk_spin_button_set_adjustment (GTK_SPIN_BUTTON(mg->spin), GTK_ADJUSTMENT(adj));
-	if (*((int*)options[id]) > DOT_TO_MM(max))
+	if (*((int*)options[id]) > DOT_TO_MM(max) - 1) /* Ʊͤ˥ޡͤ򾯤ʤ */
 		gtk_adjustment_set_value (GTK_ADJUSTMENT(adj), (gfloat)DOT_TO_MM(def));
 
 	return;
@@ -1194,8 +1363,14 @@ margin_updata (int id, long def, long max)
 
 /* Utility  -add Mon Feb 12 2001 */
 
-static void checkInkResidual (char *);
+#if (USE_INKBOX)
+static void getInkVol (char *, InkList *);
+static void setInkboxProg (char *);
+#else
 static void setInkProgress (char *);
+#endif /* USE_INKBOX */
+
+static void checkInkResidual (char *);
 static void commandButtonClicked (GtkWidget *, char *);
 static int utilInkChecker (char*);
 static GtkWidget* createMsgErr (char*);
@@ -1214,7 +1389,7 @@ commandButtonNew (char* text)
 	button = gtk_button_new_with_label("OK");
 	gtk_signal_connect (GTK_OBJECT(button), "clicked",
 			    GTK_SIGNAL_FUNC(commandButtonClicked), text);
-/*    gtk_widget_set_usize (GTK_WIDGET(button), 0, 20); */
+	/*    gtk_widget_set_usize (GTK_WIDGET(button), 0, 20); */
 	gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
 	gtk_widget_show(button);
   
@@ -1250,30 +1425,97 @@ progressPackNew (char* text)
 }
 
 
+GtkWidget *
+inkboxPackNew (void)
+{
+	GtkWidget *hbox;
+	GdkPixmap *inkbox_pixmap;
+	GdkBitmap *inkbox_mask;
+	GdkColormap *colormap;
+
+	int i;
+
+	hbox = gtk_hbox_new(TRUE, GTK_BORDER);
+
+	for (i = 0; i < INK_NUMBER; i ++)
+	{
+		colormap = gtk_widget_get_colormap (pips_util_pack.main_widget);
+
+		inkbox_pixmap = gdk_pixmap_colormap_create_from_xpm_d (NULL,
+								       colormap, &inkbox_mask, NULL,
+							      (gchar**)pips_util_pack.inkbox_xpm);
+/*
+		inkbox_pixmap = gdk_pixmap_create_from_xpm_d (pips_util_pack.main_widget->window,
+							      &inkbox_mask, NULL,
+							      (gchar**)pips_util_pack.inkbox_xpm);
+*/
+		pips_util_pack.inkbox_widget[i] = gtk_pixmap_new(inkbox_pixmap,
+								 inkbox_mask);
+		gtk_box_pack_start(GTK_BOX(hbox),
+				   pips_util_pack.inkbox_widget[i],
+				   TRUE, TRUE, 0);
+		gtk_widget_hide (pips_util_pack.inkbox_widget[i]);
+
+		gdk_pixmap_unref (inkbox_pixmap);
+		gdk_bitmap_unref (inkbox_mask);
+	}
+	return hbox;
+}
+
 int
-getPrinterStatus (void *data)
+getInkStatus (void *data)
 {
 	char rep_buf[REPLAY_SIZE];
-	char status_command[]  = { 's', 't', 0x01, 0x00, 0x01 };
-	int nwrite, nread;
-
-	nwrite = sizeof (status_command);
-	nread = 0;
-	if (sock_write (status_command, &nwrite) < 0)
-	{
-		sock_reopen ();
-		nwrite = sizeof (status_command);
-		sock_write (status_command, &nwrite);
-	}
-  
-	if (nwrite > 0)
-	{
-		nread = REPLAY_SIZE;
-		sock_read (rep_buf, &nread);
-	}
+#ifdef	INK_CHANGE_SYSTEM 
+	int inkset;
+#endif
+	get_status (rep_buf);
 
 	checkInkResidual (rep_buf);
+
+#if  (USE_INKBOX)
+	setInkboxProg (rep_buf);
+	if (pips_util_pack.inkbox_use_flag[0] == 1)
+	{
+#else
 	setInkProgress (rep_buf);
+	if (strstr(rep_buf, "IQ:"))
+	{
+#endif
+		gtk_widget_hide (pips_util_pack.no_connect_frame);
+		gtk_widget_show (pips_util_pack.connect_frame);
+	}
+	else
+	{
+		gtk_widget_hide (pips_util_pack.connect_frame);
+		gtk_widget_show (pips_util_pack.no_connect_frame);
+	}
+
+#ifdef	INK_CHANGE_SYSTEM 
+	/* 󥯤򴹤줿å */
+        inkset = get_inkset();
+	if( strcmp( options[P_INKSET], getRscName(P_INKSET, inkset) )  ){
+
+		/* ɽ */
+		GtkWidget *widget;
+		widget = createMsgErr (_(Ink_Change));
+		gtk_widget_show (widget);
+
+		/* Ink Change System б 		 */
+		/* Ink򴹤줿Υǥե */
+  		options[P_MEDIA_TYPE]    =  getRscName( P_MEDIA_TYPE, PIPS_MED_PLAIN );
+  		options[P_HALF_TONE]     =  getRscName( P_HALF_TONE, PIPS_HT_QUALITY);
+ 		options[P_QUALITY_LEVEL] =  getRscName( P_QUALITY_LEVEL, PIPS_LV_STD );
+  		options[P_RESOLUTION]    =  getRscName( P_RESOLUTION, 360 );
+  		options[P_HIGH_SPEED]    =  getRscName( P_HIGH_SPEED, PIPS_HS_OFF );
+  		options[P_MICRO_WEAVE]   =  getRscName( P_MICRO_WEAVE,PIPS_MW_ON );
+
+		/* ߤΥ󥯤 */
+  		options[P_INKSET ]       =  getRscName( P_INKSET, inkset );
+  		commonSetOptionsSensitive ();
+	}
+#endif
+
 
 	return 1;		       /* timerƤӽФؿTRUE֤ʤȽλƤޤ */
 }
@@ -1301,6 +1543,7 @@ checkInkResidual (char *buf)
 	return;
 }
 
+#if (USE_INKBOX==0)
 static void
 setInkProgress (char *buf)
 {
@@ -1327,7 +1570,7 @@ setInkProgress (char *buf)
 		strncpy (C, point + 5, 2);
 		strncpy (M, point + 7, 2);
 		strncpy (Y, point + 9, 2);
-      
+
       		if (point[11] != ';')	/* 6 ink */
 		{
 			strncpy(LC, point + 11, 2);
@@ -1354,6 +1597,7 @@ setInkProgress (char *buf)
 		rest = strtol (DY, &stopstring, 16);
 		if ((rest >= 0) && ((gint)rest < color_rest)) color_rest = (gint)rest; 
 
+
 		gtk_progress_bar_update(GTK_PROGRESS_BAR(pips_util_pack.black_prog),
 					(gfloat)black_rest / 100.0);
 		gtk_progress_bar_update(GTK_PROGRESS_BAR(pips_util_pack.color_prog),
@@ -1369,6 +1613,153 @@ setInkProgress (char *buf)
 	return;
 }
 
+#else /* USE_INKBOX */
+static void
+getInkVol (char *buf, InkList *list  )
+{
+	char* lpInk;
+
+	/* 󥯼 */
+	lpInk = strstr (buf, "INK:");
+	if (lpInk){
+		char ic[7] = "0x";
+		InkNode *prev = NULL;
+
+		lpInk += 4;	/* skip "INK:" */
+		while (*lpInk != ';') {
+			InkNode *node;
+
+			node = (InkNode *)calloc(1, sizeof(InkNode));
+			if (!node) {
+				return;
+			}
+
+			memcpy(ic + 2, lpInk, 4);
+			*(ic + 6) = '\0';
+			node->id = strtol(ic, (char **)NULL, 16);
+			
+			if (prev) {
+				prev->next = node;
+				prev = prev->next;
+			} else {
+				prev = node;
+				*list = prev;
+			}
+			lpInk += 4;
+			if (*lpInk == ',') {
+				lpInk++;
+			}
+			node = node->next;
+		}
+	}
+
+	/* 󥯻̲ */
+	lpInk = strstr(buf, "IQ:");
+	if(lpInk){
+	        char ink[3];
+		char *stopstring;
+		InkNode *node = *list;
+
+		lpInk += 3;
+		memset (ink, 0, 3);
+		while (node)
+		{
+			strncpy(ink, lpInk, 2);
+			node->rest = (gint)strtol (ink, &stopstring, 16);
+			node = node->next;
+			lpInk +=2;
+			if (*lpInk == ';') break;
+		}
+	}
+}
+
+static void
+ink_list_delete (InkList list)
+{
+	InkNode *node;
+
+	while (list) {
+		node = list->next;
+		free(list);
+		list = node;
+	}
+	return;
+}
+
+
+static void
+setInkboxProg (char *buffer)
+{
+	GdkPixmap *inkbox_pixmap;
+	GdkBitmap *inkbox_mask;
+	int inkset;
+	int i;
+	InkList list;
+	InkNode *node;
+
+	list = NULL;
+	getInkVol (buffer, &list );
+
+	inkset = get_inkset ();
+
+	node = list;
+	while (node) {
+		if (node->rest < 0 || node->rest > 100)
+			pips_util_pack.inkbox_use_flag[0] = 0;
+		node = node->next;
+	}
+	
+	node = list;
+	if (pips_util_pack.inkbox_use_flag[0] != 0 && node != NULL ){
+		if (pips_util_pack.inkbox_use_flag[pips_util_pack.inkbox_counter] == 0
+		    || pips_util_pack.inkbox_counter >= INK_NUMBER)
+			pips_util_pack.inkbox_counter = 0;
+		
+		for (i = 0; i < pips_util_pack.inkbox_counter; i++) {
+			if (!node) {
+				pips_util_pack.inkbox_use_flag[0] = 0;
+				return;
+			}
+			node = node->next;
+		}
+		
+		i = pips_util_pack.inkbox_counter;
+  	
+		inkbox_chenge_volume (pips_util_pack.inkbox_xpm, node->id, node->rest);
+		inkbox_pixmap = gdk_pixmap_create_from_xpm_d(pips_util_pack.main_widget->window,
+							     &inkbox_mask, NULL,
+							     pips_util_pack.inkbox_xpm);
+		gtk_pixmap_set(GTK_PIXMAP(pips_util_pack.inkbox_widget[i]), inkbox_pixmap,inkbox_mask);
+		
+		gtk_widget_show (pips_util_pack.inkbox_widget[i]);
+ 	        pips_util_pack.inkbox_use_flag[pips_util_pack.inkbox_counter] = 1;
+		pips_util_pack.inkbox_counter++;
+	}else{
+		for (i = 0; i < INK_NUMBER; i++){
+			
+			if (node != NULL && (node->rest >= 0 && node->rest <= 100)){
+				inkbox_chenge_volume (pips_util_pack.inkbox_xpm, node->id, node->rest);
+				inkbox_pixmap = gdk_pixmap_create_from_xpm_d(pips_util_pack.main_widget->window,
+									     &inkbox_mask, NULL,
+									     (gchar**)pips_util_pack.inkbox_xpm);
+	  	                gtk_pixmap_set(GTK_PIXMAP(pips_util_pack.inkbox_widget[i]), inkbox_pixmap,inkbox_mask);
+				pips_util_pack.inkbox_use_flag[i] = 1;
+		                gtk_widget_show (pips_util_pack.inkbox_widget[i]);
+				node = node->next;
+			}else{
+				pips_util_pack.inkbox_use_flag[i] = 0;
+		                gtk_widget_hide (pips_util_pack.inkbox_widget[i]);
+			}
+		}
+	}
+
+	/* cleanup */
+	ink_list_delete(list);
+
+	return;
+}
+#endif /* USE_INKBOX */
+
 
 static void
 commandButtonClicked (GtkWidget *widget, char* text)
@@ -1377,7 +1768,7 @@ commandButtonClicked (GtkWidget *widget, char* text)
 	   int nwrite;
 	   char pattern_command[] = { 'n', 'c', 0x01, 0x00, 0x00 };
 	   char cleaning_command[] = { 'c', 'h', 0x01, 0x00, 0x01 };
-	*/
+  */
 	char pattern_command[] = {
 		0x00, 0x00, 0x00, 0x1b, 0x01, 0x40, 0x45, 0x4a,
 		0x4c, 0x20, 0x31, 0x32, 0x38, 0x34, 0x2e, 0x34,
@@ -1451,6 +1842,7 @@ commandButtonClicked (GtkWidget *widget, char* text)
 			   sock_write_abandon_reply (pattern_command, &nwrite);
 			*/
 		}
+
 		else if (!strcmp (text, _(Head_Cleaning)))
 		{
 			fp = popen (prt_command, "w");
@@ -1461,26 +1853,44 @@ commandButtonClicked (GtkWidget *widget, char* text)
 			   sock_write_abandon_reply (cleaning_command, &nwrite);
 			*/
 		}
+
 		else
 		{
 			/* !!!! ¸ */
 			if (!strcmp (text, _(Print_Head_Alignment)))
 			{
-#if PM880C || PM3500C
+#if (PM880C) || (PM3500C) 
 				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 3 --patch 2 --platen", prt_command);
-#elif PM900C || PM920C
+#elif (PM3700C) 
+				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --extension \"%s\" --ruled 3 --patch 2 --platen", prt_command, PRINTER_MODEL);
+#elif (PM900C) || (PM920C)
 				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 2 --patch 1 --platen", prt_command);
-#elif SC40S || SC20S || SP810_820 || SC60S
+#elif (SC40S) || (SC20S) || (SP810_820) || (PM730C) || (SC60S) || (SC41_42S) \
+   || (SC61_62S) || (PM740C) || (PM740DU) || (CL760) || (SC43S) || (SP830U)
 				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 3 --rpath " RULED_PATH , prt_command);
-#elif SC980
+#elif (SC980)
 				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 2", prt_command);
+#elif (PM830C)
+				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 3 --patch 2 --ppath " PATCH_PATH , prt_command);
+#elif (SC70S) || (SC80S)
+				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 4 --band 1 --bpath " BAND_PATH , prt_command);
+#elif (PM890C) || (PM950C) || (PM850PT) || (PM840C) || (SP960) || (SP925) \
+   || (PM870C) || (PM930C) || (PM860PT) || (SP2100_2200) || (PM4000PX) || (PM940C)
+				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --extension \"%s\" --ppath " PATCH_PATH , prt_command, PRINTER_MODEL);
+#elif  (SC82S) || (PXV700)
+sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --extension \"%s\" --rpath " RULED_PATH " --bpath " BAND_PATH , prt_command, PRINTER_MODEL);
 #else
 				sprintf (navi_command, NAVI_PATH " --alignment --printer \"%s\" --ruled 3", prt_command);
 #endif
 			}
 			else if (!strcmp (text, _(Ink_Chenge)))
 				sprintf (navi_command, NAVI_PATH " --ink");
-	  
+
+			else if (!strcmp (text, _(Auto_Cutter_Adjustment)))
+				sprintf (navi_command, NAVI_PATH " --cut --printer \"%s\" --extension \"%s\" --cpath " CUT_PATH, prt_command, PRINTER_MODEL);
+/*
+			fprintf (stderr, "Debug : navi_command : %s\n", navi_command); 
+*/
 			strcat (navi_command, " 2> /dev/null");
 			system (navi_command);
 		}
@@ -1530,13 +1940,20 @@ createMsgErr (char* text)
 	else if (!strcmp (text, _(Print_Head_Alignment)))
 		label = gtk_label_new (_(Head_Alignment_Err_Msg));
 
+	else if (!strcmp (text, _(Ink_Change)))
+		label = gtk_label_new (_(Ink_Change_Msg));
+
 	else
 		label = gtk_label_new (_(Utility_Err_Msg));
 
 
 	msg_dialog = gtk_dialog_new ();
 	gtk_object_set_data (GTK_OBJECT (msg_dialog), "msg_err", msg_dialog);
-	gtk_window_set_title (GTK_WINDOW (msg_dialog), _("Error"));
+	
+	/* Ink Change ξ ȥѹ */
+	gtk_window_set_title (GTK_WINDOW (msg_dialog), 
+		!strcmp (text, _(Ink_Change)) ? _("Ink Change System"): _("Error"));
+	
 	GTK_WINDOW (msg_dialog)->type = GTK_WINDOW_DIALOG;
 	gtk_window_set_modal (GTK_WINDOW (msg_dialog), TRUE);
 	gtk_window_set_policy (GTK_WINDOW (msg_dialog), FALSE, FALSE, FALSE);
